"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.observable = void 0;
var tslib_1 = require("tslib");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
function observable(initial) {
    var getInitial = function () {
        if (Array.isArray(initial)) {
            return initial.reduce(function (acc, next) {
                acc[next.toString()] = undefined;
                return acc;
            }, {});
        }
        else {
            return initial || {};
        }
    };
    var values = tslib_1.__assign({}, getInitial());
    var keys = Object.keys(values);
    var dispose$ = new rxjs_1.Subject();
    var _events$ = new rxjs_1.Subject();
    var events$ = _events$.pipe((0, operators_1.takeUntil)(dispose$), (0, operators_1.share)());
    var changing$ = events$.pipe((0, operators_1.filter)(function (e) { return e.type === 'PROP/setting'; }), (0, operators_1.map)(function (e) { return e.payload; }), (0, operators_1.share)());
    var changed$ = events$.pipe((0, operators_1.filter)(function (e) { return e.type === 'PROP/set'; }), (0, operators_1.map)(function (e) { return e.payload; }), (0, operators_1.share)());
    var obj = {
        $: { dispose$: dispose$.pipe((0, operators_1.share)()), events$: events$ },
        changing$: changing$,
        changed$: changed$,
        get isDisposed() {
            return dispose$.isStopped;
        },
        dispose: function () {
            dispose$.next();
            dispose$.complete();
        },
        toObject: function () {
            return keys.reduce(function (acc, key) {
                var _a;
                return (tslib_1.__assign(tslib_1.__assign({}, acc), (_a = {}, _a[key] = obj[key], _a)));
            }, {});
        },
    };
    keys.forEach(function (key) {
        Object.defineProperty(obj, key, {
            get: function () {
                var current = values[key];
                var result = current;
                var isModified = false;
                var before = {
                    key: key,
                    get value() {
                        return current;
                    },
                    get isModified() {
                        return isModified;
                    },
                    modify: function (value) {
                        result = value;
                        isModified = true;
                    },
                };
                _events$.next({ type: 'PROP/getting', payload: before });
                _events$.next({ type: 'PROP/get', payload: { key: key, value: result } });
                return result;
            },
            set: function (to) {
                var from = values[key];
                var value = { from: from, to: to };
                var isCancelled = false;
                var before = {
                    key: key,
                    value: value,
                    get isCancelled() {
                        return isCancelled;
                    },
                    cancel: function () {
                        isCancelled = true;
                    },
                };
                _events$.next({ type: 'PROP/setting', payload: before });
                if (isCancelled) {
                    return;
                }
                values[key] = to;
                _events$.next({ type: 'PROP/set', payload: { key: key, value: value } });
            },
        });
    });
    return obj;
}
exports.observable = observable;
