import { Observable } from 'rxjs';
export declare type IProps<T extends Record<string, unknown> = any> = {
    [P in keyof T]: T[P];
};
export declare type IObservableProps<P extends Record<string, unknown> = any> = IProps<P> & {
    readonly $: {
        readonly dispose$: Observable<void>;
        readonly events$: Observable<PropEvent>;
    };
    readonly changing$: Observable<IPropChanging<P>>;
    readonly changed$: Observable<IPropChanged<P>>;
    readonly isDisposed: boolean;
    dispose(): void;
    toObject(): IProps<P>;
};
export declare type PropEvent = IPropGettingEvent | IPropGetEvent | IPropChangingEvent | IPropChangedEvent;
export declare type IPropGettingEvent<P extends IProps = any> = {
    type: 'PROP/getting';
    payload: IPropGetting<P>;
};
export declare type IPropGetting<P extends IProps = any> = {
    key: keyof P;
    value: P[keyof P];
    isModified: boolean;
    modify(value: P[keyof P]): void;
};
export declare type IPropGetEvent<P extends IProps = any> = {
    type: 'PROP/get';
    payload: IPropGet<P>;
};
export declare type IPropGet<P extends IProps = any> = {
    key: keyof P;
    value: P[keyof P];
};
export declare type IPropChangingEvent<P extends IProps = any> = {
    type: 'PROP/setting';
    payload: IPropChanging<P>;
};
export declare type IPropChanging<P extends IProps = any> = {
    key: keyof P;
    value: {
        from: P[keyof P];
        to: P[keyof P];
    };
    isCancelled: boolean;
    cancel(): void;
};
export declare type IPropChangedEvent<P extends IProps = any> = {
    type: 'PROP/set';
    payload: IPropChanged<P>;
};
export declare type IPropChanged<P extends IProps = any> = {
    key: keyof P;
    value: {
        from: P[keyof P];
        to: P[keyof P];
    };
};
