"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var rxjs_1 = require("rxjs");
var _1 = require(".");
var time_1 = require("../time");
describe('rx', function () {
    describe('exports', function () {
        it('rx.pump', function () {
            (0, chai_1.expect)(typeof _1.rx.pump.create === 'function').to.equal(true);
            (0, chai_1.expect)(typeof _1.rx.pump.connect === 'function').to.equal(true);
        });
    });
    describe('rx.debounceBuffer', function () {
        it('buffers several values', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
            var source$, buffered$, results;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        source$ = new rxjs_1.Subject();
                        buffered$ = _1.rx.debounceBuffer(source$);
                        results = [];
                        buffered$.subscribe(function (e) { return (results = tslib_1.__spreadArray(tslib_1.__spreadArray([], results, true), [e], false)); });
                        source$.next({ value: 1 });
                        source$.next({ value: 2 });
                        source$.next({ value: 3 });
                        (0, chai_1.expect)(results.length).to.eql(0);
                        return [4, time_1.time.wait(0)];
                    case 1:
                        _a.sent();
                        (0, chai_1.expect)(results.length).to.eql(1);
                        (0, chai_1.expect)(results[0]).to.eql([{ value: 1 }, { value: 2 }, { value: 3 }]);
                        return [2];
                }
            });
        }); });
        it('buffers into two groups after delay', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
            var source$, buffered$, results;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        source$ = new rxjs_1.Subject();
                        buffered$ = _1.rx.debounceBuffer(source$, 10);
                        results = [];
                        buffered$.subscribe(function (e) { return (results = tslib_1.__spreadArray(tslib_1.__spreadArray([], results, true), [e], false)); });
                        source$.next(1);
                        source$.next(2);
                        return [4, time_1.time.wait(5)];
                    case 1:
                        _a.sent();
                        source$.next(3);
                        return [4, time_1.time.wait(10)];
                    case 2:
                        _a.sent();
                        source$.next(4);
                        return [4, time_1.time.wait(10)];
                    case 3:
                        _a.sent();
                        source$.next(5);
                        source$.next(6);
                        return [4, time_1.time.wait(50)];
                    case 4:
                        _a.sent();
                        (0, chai_1.expect)(results.length).to.eql(3);
                        (0, chai_1.expect)(results[0]).to.eql([1, 2, 3]);
                        (0, chai_1.expect)(results[1]).to.eql([4]);
                        (0, chai_1.expect)(results[2]).to.eql([5, 6]);
                        return [2];
                }
            });
        }); });
    });
    describe('rx.event | rx.payload', function () {
        it('rx.event', function () {
            var source$ = new rxjs_1.Subject();
            var fired = [];
            _1.rx.event(source$, 'TYPE/foo').subscribe(function (e) { return fired.push(e); });
            source$.next({ type: 'TYPE/bar', payload: { msg: 'hello' } });
            source$.next({ type: 'TYPE/foo', payload: { count: 123 } });
            source$.next({ type: 'TYPE/bar', payload: { msg: 'hello' } });
            (0, chai_1.expect)(fired.length).to.eql(1);
            (0, chai_1.expect)(fired[0].type).to.eql('TYPE/foo');
            (0, chai_1.expect)(fired[0].payload).to.eql({ count: 123 });
        });
        it('rx.payload', function () {
            var source$ = new rxjs_1.Subject();
            var fired = [];
            _1.rx.payload(source$, 'TYPE/foo').subscribe(function (e) { return fired.push(e); });
            source$.next({ type: 'TYPE/bar', payload: { msg: 'hello' } });
            source$.next({ type: 'TYPE/foo', payload: { count: 123 } });
            source$.next({ type: 'TYPE/bar', payload: { msg: 'hello' } });
            (0, chai_1.expect)(fired.length).to.eql(1);
            (0, chai_1.expect)(fired[0]).to.eql({ count: 123 });
        });
    });
    describe('rx.isEvent', function () {
        var test = function (input, expected) {
            (0, chai_1.expect)(_1.rx.isEvent(input)).to.eql(expected);
        };
        it('is an event', function () {
            test({ type: 'MyEvent', payload: {} }, true);
        });
        it('is not an event', function () {
            test(undefined, false);
            test(null, false);
            test(1, false);
            test(true, false);
            test('two', false);
            test({}, false);
            test({ type: 123, payload: {} }, false);
            test({ type: 'FOO' }, false);
            test({ type: 'FOO', payload: 123 }, false);
        });
        it('is an event of given type', function () {
            var test = function (input, type, expected) {
                (0, chai_1.expect)(_1.rx.isEvent(input, type)).to.eql(expected);
            };
            test(undefined, 'foo', false);
            test(null, 'foo', false);
            test(123, 'foo', false);
            test({}, 'foo', false);
            test({ type: 'foo', payload: {} }, 'bar', false);
            test({ type: 'foo', payload: {} }, 'foo', true);
            test({ type: 'foo/bar', payload: {} }, { startsWith: 'foo/bar' }, true);
            test({ type: 'foo/bar', payload: {} }, { startsWith: 'foo/' }, true);
            test({ type: 'foo/bar', payload: {} }, { startsWith: 'foo' }, true);
            test({ type: 'foo', payload: {} }, '  foo  ', false);
            test({ type: 'foo', payload: {} }, 123, false);
            test({ type: 'foo', payload: {} }, null, false);
            test({ type: 'foo', payload: {} }, {}, false);
            test({ type: 'foo/bar', payload: {} }, { startsWith: undefined }, false);
            test({ type: 'foo/bar', payload: {} }, { startsWith: null }, false);
        });
    });
    describe('rx.disposable', function () {
        it('method: dispose', function () {
            var _a = _1.rx.disposable(), dispose$ = _a.dispose$, dispose = _a.dispose;
            var count = 0;
            dispose$.subscribe(function () { return count++; });
            dispose();
            dispose();
            dispose();
            (0, chai_1.expect)(count).to.eql(1);
        });
        it('until$', function () {
            var until$ = new rxjs_1.Subject();
            var dispose$ = _1.rx.disposable(until$).dispose$;
            var count = 0;
            dispose$.subscribe(function () { return count++; });
            (0, chai_1.expect)(count).to.eql(0);
            until$.next(123);
            until$.next(456);
            (0, chai_1.expect)(count).to.eql(1);
        });
        it('rx.done() - fires and completes the subject', function () {
            var dispose$ = new rxjs_1.Subject();
            var count = 0;
            dispose$.subscribe(function (e) { return count++; });
            _1.rx.done(dispose$);
            _1.rx.done(dispose$);
            _1.rx.done(dispose$);
            (0, chai_1.expect)(count).to.eql(1);
        });
    });
    describe('rx.asPromise', function () {
        describe('first', function () {
            it('resolves first response', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
                var $, promise, res;
                return tslib_1.__generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            $ = new rxjs_1.Subject();
                            promise = _1.rx.asPromise.first(_1.rx.payload($, 'foo'));
                            $.next({ type: 'foo', payload: { count: 1 } });
                            $.next({ type: 'foo', payload: { count: 2 } });
                            $.next({ type: 'foo', payload: { count: 3 } });
                            return [4, promise];
                        case 1:
                            res = _a.sent();
                            (0, chai_1.expect)(res.payload).to.eql({ count: 1 });
                            (0, chai_1.expect)(res.error).to.eql(undefined);
                            return [2];
                    }
                });
            }); });
            it('error: completed observable', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
                var $, res;
                var _a, _b;
                return tslib_1.__generator(this, function (_c) {
                    switch (_c.label) {
                        case 0:
                            $ = new rxjs_1.Subject();
                            $.complete();
                            return [4, _1.rx.asPromise.first(_1.rx.payload($, 'foo'))];
                        case 1:
                            res = _c.sent();
                            (0, chai_1.expect)(res.payload).to.eql(undefined);
                            (0, chai_1.expect)((_a = res.error) === null || _a === void 0 ? void 0 : _a.code).to.eql('completed');
                            (0, chai_1.expect)((_b = res.error) === null || _b === void 0 ? void 0 : _b.message).to.include('The given observable has already "completed"');
                            return [2];
                    }
                });
            }); });
            it('error: timeout', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
                var $, res;
                var _a, _b;
                return tslib_1.__generator(this, function (_c) {
                    switch (_c.label) {
                        case 0:
                            $ = new rxjs_1.Subject();
                            return [4, _1.rx.asPromise.first(_1.rx.payload($, 'foo'), { timeout: 10 })];
                        case 1:
                            res = _c.sent();
                            (0, chai_1.expect)(res.payload).to.eql(undefined);
                            (0, chai_1.expect)((_a = res.error) === null || _a === void 0 ? void 0 : _a.code).to.eql('timeout');
                            (0, chai_1.expect)((_b = res.error) === null || _b === void 0 ? void 0 : _b.message).to.include('Timed out after 10 msecs');
                            return [2];
                    }
                });
            }); });
            it('error: timeout ("op")', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
                var op, $, res;
                var _a, _b, _c;
                return tslib_1.__generator(this, function (_d) {
                    switch (_d.label) {
                        case 0:
                            op = 'foobar';
                            $ = new rxjs_1.Subject();
                            return [4, _1.rx.asPromise.first(_1.rx.payload($, 'foo'), { op: op, timeout: 10 })];
                        case 1:
                            res = _d.sent();
                            (0, chai_1.expect)(res.payload).to.eql(undefined);
                            (0, chai_1.expect)((_a = res.error) === null || _a === void 0 ? void 0 : _a.code).to.eql('timeout');
                            (0, chai_1.expect)((_b = res.error) === null || _b === void 0 ? void 0 : _b.message).to.include('Timed out after 10 msecs');
                            (0, chai_1.expect)((_c = res.error) === null || _c === void 0 ? void 0 : _c.message).to.include("[".concat(op, "]"));
                            return [2];
                    }
                });
            }); });
        });
    });
});
