"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var rxjs_1 = require("rxjs");
var _1 = require(".");
describe('rx.bus', function () {
    describe('isBus', function () {
        it('is bus', function () {
            var test = function (input) {
                (0, chai_1.expect)(_1.rx.isBus(input)).to.eql(true);
            };
            test({ $: new rxjs_1.Observable(), fire: function () { return null; } });
            test(_1.rx.bus());
        });
        it('is not a bus', function () {
            var test = function (input) {
                (0, chai_1.expect)(_1.rx.isBus(input)).to.eql(false);
            };
            test(undefined);
            test(null);
            test(123);
            test({});
            test([123, {}]);
            test({ event$: new rxjs_1.Observable() });
            test({ $: new rxjs_1.Observable() });
            test({ fire: function () { return null; } });
        });
    });
    describe('busAsType', function () {
        it('changes event type', function () {
            var bus1 = _1.rx.bus();
            var fired = [];
            bus1.$.subscribe(function (e) { return fired.push(e); });
            var bus2 = _1.rx.busAsType(bus1);
            bus2.fire({ type: 'Event/bar', payload: {} });
            (0, chai_1.expect)(fired.length).to.eql(1);
            (0, chai_1.expect)(fired[0].type).to.eql('Event/bar');
        });
    });
    describe('bus (factory)', function () {
        it('_instance (hidden "id")', function () {
            var bus = _1.rx.bus();
            var _instance = bus._instance;
            (0, chai_1.expect)(typeof _instance).to.eql('string');
            (0, chai_1.expect)(_instance.startsWith('bus.')).to.eql(true);
            (0, chai_1.expect)(_instance.length).to.greaterThan('bus.'.length);
        });
        it('rx.bus.instance(...)', function () {
            var bus = _1.rx.bus();
            var _instance = bus._instance;
            (0, chai_1.expect)(_1.rx.bus.instance(bus)).to.eql(_instance);
            (0, chai_1.expect)(_1.rx.bus.instance({})).to.eql('');
        });
        it('create: new observable (no param, no type)', function () {
            var bus = _1.rx.bus();
            var fired = [];
            bus.$.subscribe(function (e) { return fired.push(e); });
            bus.fire({ type: 'ANY', payload: {} });
            (0, chai_1.expect)(fired.length).to.eql(1);
            (0, chai_1.expect)(fired[0].type).to.eql('ANY');
        });
        it('create: use given subject', function () {
            var source$ = new rxjs_1.Subject();
            var bus = _1.rx.bus(source$);
            var fired = [];
            bus.$.subscribe(function (e) { return fired.push(e); });
            source$.next({ type: 'ANY', payload: {} });
            bus.fire({ type: 'Event/foo', payload: {} });
            (0, chai_1.expect)(fired.length).to.eql(2);
            (0, chai_1.expect)(fired[0].type).to.eql('ANY');
            (0, chai_1.expect)(fired[1].type).to.eql('Event/foo');
        });
        it('create: use given bus', function () {
            var bus1 = _1.rx.bus();
            var bus2 = _1.rx.bus(bus1);
            (0, chai_1.expect)(bus2).to.equal(bus1);
        });
        it('filters out non-standard [event] objects from the stream', function () {
            var source$ = new rxjs_1.Subject();
            var bus = _1.rx.bus(source$);
            var fired = [];
            bus.$.subscribe(function (e) { return fired.push(e); });
            source$.next(undefined);
            source$.next(null);
            source$.next(1);
            source$.next(true);
            source$.next('two');
            source$.next({});
            source$.next({ type: 123, payload: {} });
            source$.next({ type: 'FOO' });
            source$.next({ type: 'FOO', payload: 123 });
            (0, chai_1.expect)(fired.length).to.eql(0);
        });
        it('bus.isBus', function () {
            (0, chai_1.expect)(_1.rx.bus.isBus).to.equal(_1.rx.isBus);
        });
        it('bus.asType', function () {
            (0, chai_1.expect)(_1.rx.bus.asType).to.equal(_1.rx.busAsType);
        });
        it('bus.pump', function () {
            (0, chai_1.expect)(_1.rx.bus.pump).to.equal(_1.rx.pump);
        });
    });
});
