"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pump = void 0;
var operators_1 = require("rxjs/operators");
var rx_bus_util_1 = require("./rx.bus.util");
var rx_disposable_1 = require("./rx.disposable");
exports.Pump = {
    create: function (bus, options) {
        if (options === void 0) { options = {}; }
        if (!(0, rx_bus_util_1.isBus)(bus))
            throw new Error('Not a valid event-bus');
        var disposed = false;
        var dispose$ = (0, rx_disposable_1.disposable)(options.dispose$).dispose$;
        dispose$.subscribe(function () { return (disposed = true); });
        var allow = function (direction, event) {
            return typeof options.filter !== 'function' ? true : options.filter({ direction: direction, event: event });
        };
        return {
            id: Util.asPumpId(bus),
            in: function (fn) {
                bus.$.pipe((0, operators_1.takeUntil)(dispose$), (0, operators_1.filter)(function (e) { return allow('In', e); })).subscribe(fn);
            },
            out: function (e) {
                if (disposed)
                    return;
                if (!allow('Out', e))
                    return;
                bus.fire(e);
            },
        };
    },
    connect: function (pump, options) {
        if (options === void 0) { options = {}; }
        var _a = (0, rx_disposable_1.disposable)(options.dispose$), dispose = _a.dispose, dispose$ = _a.dispose$;
        dispose$.subscribe(function () { return (connection.alive = false); });
        var allow = function (direction, event) {
            return typeof options.filter !== 'function' ? true : options.filter({ direction: direction, event: event });
        };
        var connection = {
            alive: true,
            dispose: dispose,
            dispose$: dispose$,
            to: function (bus) {
                if (Util.asPumpId(bus) === pump.id) {
                    var msg = "Cannot connect event-bus \"".concat((0, rx_bus_util_1.instance)(bus), "\" to a pump containing itself");
                    throw new Error(msg);
                }
                var ignore = {};
                pump.in(function (e) {
                    if (e === ignore.out || !connection.alive)
                        return;
                    if (!allow('In', e))
                        return;
                    ignore.in = e;
                    bus.fire(e);
                    ignore.in = undefined;
                });
                bus.$.pipe((0, operators_1.takeUntil)(dispose$), (0, operators_1.filter)(function (e) { return e !== ignore.in; }), (0, operators_1.filter)(function (e) { return allow('Out', e); })).subscribe(function (e) {
                    ignore.out = e;
                    pump.out(e);
                    ignore.out = undefined;
                });
                return connection;
            },
            filter: function (fn) {
                var filter = function (e) {
                    if (!fn(e))
                        return false;
                    if (typeof options.filter === 'function' && !options.filter(e))
                        return false;
                    return true;
                };
                return exports.Pump.connect(pump, { dispose$: dispose$, filter: filter });
            },
        };
        return connection;
    },
};
var Util = {
    asPumpId: function (bus) { return "pump:".concat((0, rx_bus_util_1.instance)(bus)); },
};
