"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var rxjs_1 = require("rxjs");
var delay_1 = require("./delay");
var now = function () { return new Date().getTime(); };
describe('delay', function () {
    it('delays then executes', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var startedAt, count;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    startedAt = now();
                    count = 0;
                    (0, chai_1.expect)(now() - startedAt).to.be.lessThan(8);
                    return [4, (0, delay_1.delay)(10, function () { return (count += 1); })];
                case 1:
                    _a.sent();
                    (0, chai_1.expect)(now() - startedAt).to.be.greaterThan(8);
                    (0, chai_1.expect)(count).to.eql(1);
                    return [2];
            }
        });
    }); });
    it('does not fail when no callback is specified', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var startedAt;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    startedAt = now();
                    (0, chai_1.expect)(now() - startedAt).to.be.lessThan(8);
                    return [4, (0, delay_1.delay)(10)];
                case 1:
                    _a.sent();
                    (0, chai_1.expect)(now() - startedAt).to.be.greaterThan(8);
                    return [2];
            }
        });
    }); });
    it('cancels delay (await promise)', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var startedAt, count, res;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    startedAt = now();
                    count = 0;
                    (0, chai_1.expect)(now() - startedAt).to.be.lessThan(8);
                    res = (0, delay_1.delay)(10, function () { return count++; });
                    (0, chai_1.expect)(res.isCancelled).to.eql(false);
                    (0, chai_1.expect)(typeof res === 'object').to.eql(true);
                    res.cancel();
                    (0, chai_1.expect)(res.isCancelled).to.eql(true);
                    return [4, res];
                case 1:
                    _a.sent();
                    (0, chai_1.expect)(now() - startedAt).to.be.lessThan(8);
                    (0, chai_1.expect)(count).to.eql(0);
                    return [2];
            }
        });
    }); });
    it('returns value from callback', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var res1, res2;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, (0, delay_1.delay)(5, function () { return undefined; })];
                case 1:
                    res1 = _a.sent();
                    return [4, (0, delay_1.delay)(5, function () { return 123; })];
                case 2:
                    res2 = _a.sent();
                    (0, chai_1.expect)(res1).to.eql(undefined);
                    (0, chai_1.expect)(res2).to.eql(123);
                    return [2];
            }
        });
    }); });
    it('stores return value on callback', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var res;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    res = (0, delay_1.delay)(5, function () { return 123; });
                    (0, chai_1.expect)(res.result).to.eql(undefined);
                    return [4, res];
                case 1:
                    _a.sent();
                    (0, chai_1.expect)(res.result).to.eql(123);
                    return [2];
            }
        });
    }); });
});
describe('wait', function () {
    it('wait: msecs', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var startedAt;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    startedAt = now();
                    (0, chai_1.expect)(now() - startedAt).to.be.lessThan(10);
                    return [4, (0, delay_1.wait)(15)];
                case 1:
                    _a.sent();
                    (0, chai_1.expect)(now() - startedAt).to.be.greaterThan(10);
                    return [2];
            }
        });
    }); });
    it('wait: for observable', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var startedAt, ob$;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    startedAt = now();
                    (0, chai_1.expect)(now() - startedAt).to.be.lessThan(10);
                    ob$ = new rxjs_1.Subject();
                    (0, delay_1.delay)(15, function () { return ob$.next(); });
                    return [4, (0, delay_1.wait)(ob$)];
                case 1:
                    _a.sent();
                    (0, chai_1.expect)(now() - startedAt).to.be.greaterThan(10);
                    return [2];
            }
        });
    }); });
});
