"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var _1 = require(".");
var duration_1 = require("./duration");
var MSEC = 1;
var SEC = MSEC * 1000;
var MIN = SEC * 60;
var HOUR = MIN * 60;
var DAY = HOUR * 24;
describe('duration', function () {
    it('time.duration(...)', function () {
        var res1 = _1.time.duration(123);
        var res2 = _1.time.duration('3.5h');
        (0, chai_1.expect)(res1.msec).to.eql(123);
        (0, chai_1.expect)(res2.hour).to.eql(3.5);
    });
    it('toString()', function () {
        var res = _1.time.duration(1025);
        (0, chai_1.expect)(res.msec).to.eql(1025);
        (0, chai_1.expect)(res.toString()).to.eql('1s');
        (0, chai_1.expect)(res.toString('ms')).to.eql('1025ms');
    });
    it('toString (round)', function () {
        var duration = _1.time.duration(1258);
        var res1 = duration.toString();
        var res2 = duration.toString({ round: 1 });
        var res3 = duration.toString({ round: 3 });
        (0, chai_1.expect)(res1).to.eql('1s');
        (0, chai_1.expect)(res2).to.eql('1.3s');
        (0, chai_1.expect)(res3).to.eql('1.258s');
    });
    it('forces anything less than zero to -1', function () {
        (0, chai_1.expect)(duration_1.Duration.create(-0.000001).msec).to.eql(-1);
    });
    it('ok: true', function () {
        (0, chai_1.expect)(_1.time.duration(123).ok).to.eql(true);
        (0, chai_1.expect)(_1.time.duration(0).ok).to.eql(true);
    });
    it('ok: false', function () {
        (0, chai_1.expect)(_1.time.duration(-1).ok).to.eql(false);
        (0, chai_1.expect)(_1.time.duration(-0.001).ok).to.eql(false);
    });
    it('parse', function () {
        var test = function (input, msecs) {
            var res = duration_1.Duration.parse(input);
            (0, chai_1.expect)(res.msec).to.eql(msecs);
        };
        test(0, 0);
        test(123, 123);
        test(123.5, 123.5);
        test('0', 0);
        test('  0   ', 0);
        test('123ms', 123);
        test('123 ms', 123);
        test('123.5ms  ', 123.5);
        test('1s', SEC);
        test('1m', MIN);
        test('1h', HOUR);
        test('1d', DAY);
        test('1sec', SEC);
        test('1min', MIN);
        test('1hour', HOUR);
        test('1day', DAY);
        test('1 sec', SEC);
        test('1 min', MIN);
        test('1 hour', HOUR);
        test('1 day', DAY);
        test('', -1);
        test('-1', -1);
        test('-10s', -1);
        test('123. 5ms  ', -1);
        test('123 .5ms  ', -1);
        test('123 .5', -1);
    });
});
