"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Duration = void 0;
var day = require("dayjs");
var value_math_1 = require("../value/value.math");
var value_to_1 = require("../value/value.to");
var MSEC = 1;
var SEC = MSEC * 1000;
var MIN = SEC * 60;
var HOUR = MIN * 60;
var DAY = HOUR * 24;
var Duration = (function () {
    function Duration(msec, options) {
        if (options === void 0) { options = {}; }
        this.msec = msec < 0 ? -1 : msec;
        this.round = options.round === undefined ? 1 : options.round;
    }
    Duration.create = function (msec, options) {
        return new Duration(msec, options);
    };
    Duration.format = function (msec, unit, round) {
        if (round === void 0) { round = 0; }
        var to = Duration.to;
        switch (unit) {
            case 'ms':
            case 'msec':
                return "".concat(msec, "ms");
            case 's':
            case 'sec':
                return "".concat(to.sec(msec, round), "s");
            case 'm':
            case 'min':
                return "".concat(to.min(msec, round), "m");
            case 'h':
            case 'hour':
                return "".concat(to.hour(msec, round), "h");
            case 'd':
            case 'day':
                return "".concat(to.day(msec, round), "d");
            default:
                throw new Error("Unit '".concat(unit, "' not supported "));
        }
    };
    Duration.parse = function (input, options) {
        if (options === void 0) { options = {}; }
        var done = function (msecs) { return Duration.create(msecs, options); };
        if (typeof input === 'number') {
            return done(input);
        }
        input = (input || '').trim();
        var matchedDigits = input.match(/(\d*\.?)\d*/);
        var digits = matchedDigits && matchedDigits[0] ? (0, value_to_1.toNumber)(matchedDigits[0]) : -1;
        if (digits < 0) {
            return done(-1);
        }
        input = input.substring(digits.toString().length).trim().toLowerCase();
        switch (input) {
            case '':
            case 'ms':
            case 'msec':
                return done(digits);
            case 's':
            case 'sec':
                return done(digits * SEC);
            case 'm':
            case 'min':
                return done(digits * MIN);
            case 'h':
            case 'hour':
                return done(digits * HOUR);
            case 'd':
            case 'day':
                return done(digits * DAY);
            default:
                return done(-1);
        }
    };
    Object.defineProperty(Duration.prototype, "ok", {
        get: function () {
            return this.msec >= 0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Duration.prototype, "sec", {
        get: function () {
            return Duration.to.sec(this.msec, this.round);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Duration.prototype, "min", {
        get: function () {
            return Duration.to.min(this.msec, this.round);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Duration.prototype, "hour", {
        get: function () {
            return Duration.to.hour(this.msec, this.round);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Duration.prototype, "day", {
        get: function () {
            return Duration.to.day(this.msec, this.round);
        },
        enumerable: false,
        configurable: true
    });
    Duration.prototype.toString = function (unit) {
        var msecs = this.msec;
        var format = Duration.format;
        var options = typeof unit === 'object' ? unit : { unit: unit };
        var round = typeof options.round === 'number' ? options.round : 0;
        if (options.unit !== undefined) {
            return format(msecs, options.unit, round);
        }
        if (msecs < SEC) {
            return format(msecs, 'ms', round);
        }
        if (msecs < MIN) {
            return format(msecs, 's', round);
        }
        if (msecs < HOUR) {
            return format(msecs, 'm', round);
        }
        if (msecs < DAY) {
            return format(msecs, 'h', round);
        }
        return format(msecs, 'd', round);
    };
    Duration.to = {
        sec: function (msec, precision) { return (0, value_math_1.round)(msec / 1000, precision); },
        min: function (msec, precision) { return (0, value_math_1.round)(msec / 1000 / 60, precision); },
        hour: function (msec, precision) { return (0, value_math_1.round)(msec / 1000 / 60 / 60, precision); },
        day: function (msec, precision) { return (0, value_math_1.round)(msec / 1000 / 60 / 60 / 24, precision); },
        date: function (input) { return day(input).toDate(); },
    };
    return Duration;
}());
exports.Duration = Duration;
