"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var _1 = require(".");
var FORMAT = 'YYYY-MM-DD hh:mm:ss';
var format = function (date) { return _1.time.day(date).format(FORMAT); };
describe('timer', function () {
    it('starts with current date', function () {
        var now = _1.time.day().format(FORMAT);
        var timer = _1.time.timer();
        (0, chai_1.expect)(format(timer.startedAt)).to.eql(now);
    });
    it('starts with given date', function () {
        var start = _1.time.day().add(1, 'd').toDate();
        var timer = _1.time.timer(start);
        (0, chai_1.expect)(format(timer.startedAt)).to.eql(format(start));
        (0, chai_1.expect)(format(timer.startedAt)).to.not.eql(format(new Date()));
    });
    it('waits', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var timer;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    timer = _1.time.timer();
                    (0, chai_1.expect)(timer.elapsed.msec).to.lessThan(5);
                    return [4, _1.time.wait(10)];
                case 1:
                    _a.sent();
                    (0, chai_1.expect)(timer.elapsed.msec).to.greaterThan(6);
                    (0, chai_1.expect)(timer.elapsed.msec).to.greaterThan(6);
                    return [2];
            }
        });
    }); });
    it('reports elapsed seconds', function () {
        var start = _1.time.day().subtract(1, 'm').subtract(30, 's').subtract(259, 'ms').toDate();
        (0, chai_1.expect)(_1.time.timer(start).elapsed.sec).to.eql(90.3);
        (0, chai_1.expect)(_1.time.timer(start, { round: 0 }).elapsed.sec).to.eql(90);
        var timer = _1.time.timer(start);
        (0, chai_1.expect)(timer.elapsed.toString('s')).to.eql('90s');
        (0, chai_1.expect)(timer.elapsed.toString('sec')).to.eql('90s');
    });
    it('reports elapsed minutes', function () {
        var start = _1.time.day().subtract(5, 'm').subtract(24, 's').subtract(123, 'ms').toDate();
        (0, chai_1.expect)(_1.time.timer(start, { round: 0 }).elapsed.min).to.eql(5);
        (0, chai_1.expect)(_1.time.timer(start, { round: 3 }).elapsed.min).to.eql(5.402);
        (0, chai_1.expect)(_1.time.timer(start).elapsed.min).to.eql(5.4);
        var timer = _1.time.timer(start);
        (0, chai_1.expect)(timer.elapsed.toString('m')).to.eql('5m');
        (0, chai_1.expect)(timer.elapsed.toString('min')).to.eql('5m');
    });
    it('reports elapsed hours', function () {
        var start = _1.time
            .day()
            .subtract(2, 'h')
            .subtract(37, 'm')
            .subtract(48, 's')
            .subtract(123, 'ms')
            .toDate();
        (0, chai_1.expect)(_1.time.timer(start).elapsed.hour).to.eql(2.6);
        (0, chai_1.expect)(_1.time.timer(start, { round: 0 }).elapsed.hour).to.eql(3);
        (0, chai_1.expect)(_1.time.timer(start, { round: 1 }).elapsed.hour).to.eql(2.6);
        (0, chai_1.expect)(_1.time.timer(start, { round: 2 }).elapsed.hour).to.eql(2.63);
        var timer = _1.time.timer(start);
        (0, chai_1.expect)(timer.elapsed.toString('h')).to.eql('3h');
        (0, chai_1.expect)(timer.elapsed.toString('hour')).to.eql('3h');
    });
    it('reports elapsed days', function () {
        var start = _1.time
            .day()
            .subtract(4, 'd')
            .subtract(18, 'h')
            .subtract(5, 'm')
            .subtract(123, 'ms')
            .toDate();
        (0, chai_1.expect)(_1.time.timer(start).elapsed.day).to.eql(4.8);
        (0, chai_1.expect)(_1.time.timer(start, { round: 0 }).elapsed.day).to.eql(5);
        (0, chai_1.expect)(_1.time.timer(start, { round: 1 }).elapsed.day).to.eql(4.8);
        (0, chai_1.expect)(_1.time.timer(start, { round: 2 }).elapsed.day).to.eql(4.75);
        var timer = _1.time.timer(start);
        (0, chai_1.expect)(timer.elapsed.toString('d')).to.eql('5d');
        (0, chai_1.expect)(timer.elapsed.toString('day')).to.eql('5d');
    });
    it('toString()', function () {
        var start = _1.time.day();
        var elapsed = function () { return _1.time.timer(start.toDate()).elapsed; };
        start = start.subtract(125, 'ms');
        (0, chai_1.expect)(elapsed().toString().endsWith('ms')).to.eql(true);
        start = start.subtract(10, 's');
        (0, chai_1.expect)(elapsed().toString()).to.eql('10s');
        start = start.subtract(25, 's');
        (0, chai_1.expect)(elapsed().toString()).to.eql('35s');
        start = start.subtract(24, 's');
        (0, chai_1.expect)(elapsed().toString()).to.eql('59s');
        start = start.subtract(1, 's');
        (0, chai_1.expect)(elapsed().toString()).to.eql('1m');
        start = start.subtract(15, 'm');
        (0, chai_1.expect)(elapsed().toString()).to.eql('16m');
        start = start.subtract(43, 'm');
        (0, chai_1.expect)(elapsed().toString()).to.eql('59m');
        start = start.subtract(1, 'm');
        (0, chai_1.expect)(elapsed().toString()).to.eql('1h');
        start = start.subtract(29, 'm');
        (0, chai_1.expect)(elapsed().toString()).to.eql('1h');
        start = start.subtract(1, 'm');
        (0, chai_1.expect)(elapsed().toString()).to.eql('2h');
        start = start.subtract(1, 'h');
        (0, chai_1.expect)(elapsed().toString()).to.eql('3h');
        start = start.subtract(24, 'h');
        (0, chai_1.expect)(elapsed().toString()).to.eql('1d');
        start = start.subtract(24, 'h');
        (0, chai_1.expect)(elapsed().toString()).to.eql('2d');
        start = start.subtract(48, 'h');
        (0, chai_1.expect)(elapsed().toString()).to.eql('4d');
    });
});
