"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var _1 = require(".");
describe('compact', function () {
    it('makes no change', function () {
        (0, chai_1.expect)(_1.value.compact([1, 2, 3])).to.eql([1, 2, 3]);
    });
    it('removes null values', function () {
        (0, chai_1.expect)(_1.value.compact([1, null, 3, null])).to.eql([1, 3]);
    });
    it('removes undefined values', function () {
        (0, chai_1.expect)(_1.value.compact([1, undefined, 3, undefined])).to.eql([1, 3]);
    });
    it('removes empty strings', function () {
        (0, chai_1.expect)(_1.value.compact([1, '', 3])).to.eql([1, 3]);
    });
    it('retains `false` and 0', function () {
        (0, chai_1.expect)(_1.value.compact([0, 1, false, 3])).to.eql([0, 1, false, 3]);
    });
    it('retains white space strings', function () {
        (0, chai_1.expect)(_1.value.compact([0, 1, ' ', 3])).to.eql([0, 1, ' ', 3]);
    });
});
describe('flatten', function () {
    it('makes no change', function () {
        (0, chai_1.expect)(_1.value.flatten([1, 2, 3])).to.eql([1, 2, 3]);
    });
    it('return input value if an array is not passed', function () {
        (0, chai_1.expect)(_1.value.flatten(123)).to.eql(123);
    });
    it('flattens one level deep', function () {
        (0, chai_1.expect)(_1.value.flatten([1, [2, 3]])).to.eql([1, 2, 3]);
    });
    it('flattens many levels deep', function () {
        (0, chai_1.expect)(_1.value.flatten([1, [2, [3, [4, [5, 6]]]]])).to.eql([1, 2, 3, 4, 5, 6]);
    });
});
describe('asArray', function () {
    it('already array', function () {
        var input = [{ count: 1 }, { count: 2 }, { count: 3 }];
        var res = _1.value.asArray(input);
        (0, chai_1.expect)(res).to.equal(input);
        (0, chai_1.expect)(res[0].count).to.eql(1);
    });
    it('convert to array', function () {
        var input = { count: 1 };
        var res = _1.value.asArray(input);
        (0, chai_1.expect)(res.length).to.eql(1);
        (0, chai_1.expect)(res).to.not.equal(input);
        (0, chai_1.expect)(res[0]).to.equal(input);
        (0, chai_1.expect)(res[0].count).to.eql(1);
    });
});
