"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var _1 = require(".");
describe('isPlainObject', function () {
    it('is a plain object', function () {
        (0, chai_1.expect)(_1.value.isPlainObject(Object.create({}))).to.equal(true);
        (0, chai_1.expect)(_1.value.isPlainObject(Object.create(Object.prototype))).to.equal(true);
        (0, chai_1.expect)(_1.value.isPlainObject({ foo: 123 })).to.equal(true);
        (0, chai_1.expect)(_1.value.isPlainObject({})).to.equal(true);
    });
    it('is not a plain object', function () {
        var Foo = (function () {
            function Foo() {
            }
            return Foo;
        }());
        (0, chai_1.expect)(_1.value.isPlainObject(1)).to.equal(false);
        (0, chai_1.expect)(_1.value.isPlainObject(['foo', 'bar'])).to.equal(false);
        (0, chai_1.expect)(_1.value.isPlainObject([])).to.equal(false);
        (0, chai_1.expect)(_1.value.isPlainObject(new Foo())).to.equal(false);
        (0, chai_1.expect)(_1.value.isPlainObject(null)).to.equal(false);
        (0, chai_1.expect)(_1.value.isPlainObject(Object.create(null))).to.equal(false);
    });
});
describe('value.isBoolString', function () {
    var test = function (expected, input) {
        var res = _1.value.isBoolString(input);
        (0, chai_1.expect)(res).to.eql(expected, input);
    };
    it('is a boolean', function () {
        test(true, 'true');
        test(true, 'false');
        test(true, 'True');
        test(true, 'False');
        test(true, 'TRUE');
        test(true, 'FALSE');
    });
    it('is not a boolean', function () {
        test(false, undefined);
        test(false, '');
        test(false, 'HELLO');
        test(false, { foo: 123 });
    });
});
describe('value.isNullString', function () {
    var test = function (expected, input) {
        var res = _1.value.isNullString(input);
        (0, chai_1.expect)(res).to.eql(expected, input);
    };
    it('is null', function () {
        test(true, 'null');
        test(true, '  null  ');
        test(true, 'NULL');
        test(true, 'Null');
    });
    it('is not null', function () {
        test(false, undefined);
        test(false, '');
        test(false, 'I am null');
        test(false, 'HELLO');
        test(false, 123);
        test(false, { foo: 123 });
    });
});
describe('value.isUndefinedString', function () {
    var test = function (expected, input) {
        var res = _1.value.isUndefinedString(input);
        (0, chai_1.expect)(res).to.eql(expected, input);
    };
    it('is undefined', function () {
        test(true, 'undefined');
        test(true, '  undefined  ');
        test(true, 'UNDEFINED');
        test(true, 'Undefined');
    });
    it('is not undefined', function () {
        test(false, null);
        test(false, '');
        test(false, 'I am undefined');
        test(false, 'HELLO');
        test(false, 123);
        test(false, { foo: 123 });
    });
});
describe('value.isDateString', function () {
    var test = function (expected, input) {
        var res = _1.value.isDateString(input);
        (0, chai_1.expect)(res).to.eql(expected, "".concat(input, " value is date: ").concat(expected));
    };
    it('is a date', function () {
        test(true, '2019-03-07T21:07:33.062Z');
    });
    it('is not a date', function () {
        test(false);
        test(false, undefined);
        test(false, null);
        test(false, '');
        test(false, '  ');
        test(false, 123);
        test(false, new Date());
        test(false, {});
        test(false, { date: '2019-03-07T21:07:33.062Z' });
        test(false, '  2019-03-07T21:07:33.062Z  ');
    });
});
describe('value.isBlank', function () {
    describe('blank', function () {
        it('is blank (nothing)', function () {
            (0, chai_1.expect)(_1.value.isBlank(undefined)).to.equal(true);
            (0, chai_1.expect)(_1.value.isBlank(null)).to.equal(true);
        });
        it('is blank (string)', function () {
            (0, chai_1.expect)(_1.value.isBlank('')).to.equal(true);
            (0, chai_1.expect)(_1.value.isBlank(' ')).to.equal(true);
            (0, chai_1.expect)(_1.value.isBlank('   ')).to.equal(true);
        });
        it('is blank (array)', function () {
            (0, chai_1.expect)(_1.value.isBlank([])).to.equal(true);
            (0, chai_1.expect)(_1.value.isBlank([null])).to.equal(true);
            (0, chai_1.expect)(_1.value.isBlank([undefined])).to.equal(true);
            (0, chai_1.expect)(_1.value.isBlank([undefined, null])).to.equal(true);
            (0, chai_1.expect)(_1.value.isBlank([undefined, null, ''])).to.equal(true);
        });
    });
    describe('NOT blank', function () {
        it('is not blank (string)', function () {
            (0, chai_1.expect)(_1.value.isBlank('a')).to.equal(false);
            (0, chai_1.expect)(_1.value.isBlank('   .')).to.equal(false);
        });
        it('is not blank (array)', function () {
            (0, chai_1.expect)(_1.value.isBlank([1])).to.equal(false);
            (0, chai_1.expect)(_1.value.isBlank([null, 'value'])).to.equal(false);
            (0, chai_1.expect)(_1.value.isBlank([null, '   '])).to.equal(false);
        });
        it('is not blank (other values)', function () {
            (0, chai_1.expect)(_1.value.isBlank(1)).to.equal(false);
            (0, chai_1.expect)(_1.value.isBlank({})).to.equal(false);
            (0, chai_1.expect)(_1.value.isBlank(function () { return 0; })).to.equal(false);
        });
    });
});
describe('value.isNumeric', function () {
    it('is numeric (number)', function () {
        (0, chai_1.expect)(_1.value.isNumeric(0)).to.equal(true);
        (0, chai_1.expect)(_1.value.isNumeric(1)).to.equal(true);
        (0, chai_1.expect)(_1.value.isNumeric(-1)).to.equal(true);
        (0, chai_1.expect)(_1.value.isNumeric(0.5)).to.equal(true);
        (0, chai_1.expect)(_1.value.isNumeric(123456.123456)).to.equal(true);
    });
    it('is numeric (string)', function () {
        (0, chai_1.expect)(_1.value.isNumeric('0')).to.equal(true);
        (0, chai_1.expect)(_1.value.isNumeric('1')).to.equal(true);
        (0, chai_1.expect)(_1.value.isNumeric('-1')).to.equal(true);
        (0, chai_1.expect)(_1.value.isNumeric('0.5')).to.equal(true);
        (0, chai_1.expect)(_1.value.isNumeric('123456.123456')).to.equal(true);
    });
    it('is not numeric', function () {
        (0, chai_1.expect)(_1.value.isNumeric(null)).to.equal(false);
        (0, chai_1.expect)(_1.value.isNumeric(undefined)).to.equal(false);
        (0, chai_1.expect)(_1.value.isNumeric('string')).to.equal(false);
        (0, chai_1.expect)(_1.value.isNumeric('123px')).to.equal(false);
        (0, chai_1.expect)(_1.value.isNumeric({})).to.equal(false);
        (0, chai_1.expect)(_1.value.isNumeric(new Date())).to.equal(false);
    });
});
describe('isLetter', function () {
    it('is a letter', function () {
        (0, chai_1.expect)(_1.value.isLetter('A')).to.eql(true);
        (0, chai_1.expect)(_1.value.isLetter('a')).to.eql(true);
        (0, chai_1.expect)(_1.value.isLetter('b')).to.eql(true);
        (0, chai_1.expect)(_1.value.isLetter('z')).to.eql(true);
        (0, chai_1.expect)(_1.value.isLetter('Z')).to.eql(true);
    });
    it('is not a letter', function () {
        (0, chai_1.expect)(_1.value.isLetter(undefined)).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter(null)).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter('')).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter('\n')).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter(' ')).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter('1')).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter('*')).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter('.')).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter(' a')).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter(123)).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter({})).to.eql(false);
        (0, chai_1.expect)(_1.value.isLetter(new Date())).to.eql(false);
    });
});
describe('isAlpha', function () {
    it('is alphabet letters', function () {
        (0, chai_1.expect)(_1.value.isAlpha('A')).to.eql(true);
        (0, chai_1.expect)(_1.value.isAlpha('a')).to.eql(true);
        (0, chai_1.expect)(_1.value.isAlpha('ABC')).to.eql(true);
    });
    it('is not all letters', function () {
        (0, chai_1.expect)(_1.value.isAlpha(undefined)).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha(null)).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha('')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha('\n')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha(' ')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha('1')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha('*')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha('.')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha(' a')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha(123)).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha({})).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha(new Date())).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha('A:B')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha('A-B')).to.eql(false);
        (0, chai_1.expect)(_1.value.isAlpha('A B')).to.eql(false);
    });
});
describe('hasWhitespace', function () {
    it('has whitespace', function () {
        (0, chai_1.expect)(_1.value.hasWhitespace(' ')).to.eql(true);
        (0, chai_1.expect)(_1.value.hasWhitespace('  ')).to.eql(true);
        (0, chai_1.expect)(_1.value.hasWhitespace('one two')).to.eql(true);
        (0, chai_1.expect)(_1.value.hasWhitespace(' one two ')).to.eql(true);
    });
    it('has no whitespace', function () {
        (0, chai_1.expect)(_1.value.hasWhitespace('')).to.eql(false);
        (0, chai_1.expect)(_1.value.hasWhitespace('hello')).to.eql(false);
        (0, chai_1.expect)(_1.value.hasWhitespace('123')).to.eql(false);
    });
});
describe('isEmail', function () {
    it('is not an email when empty', function () {
        (0, chai_1.expect)(_1.value.isEmail('')).to.eql(false);
        (0, chai_1.expect)(_1.value.isEmail('  ')).to.eql(false);
        (0, chai_1.expect)(_1.value.isEmail()).to.eql(false);
    });
    it('is not an email address whem not trimmed of whitespace', function () {
        (0, chai_1.expect)(_1.value.isEmail(' phil@foo.com')).to.eql(false);
        (0, chai_1.expect)(_1.value.isEmail('phil@foo.com ')).to.eql(false);
        (0, chai_1.expect)(_1.value.isEmail('  phil@foo.com ')).to.eql(false);
    });
    it('is not an email address', function () {
        (0, chai_1.expect)(_1.value.isEmail('phil@foo.c')).to.eql(false);
        (0, chai_1.expect)(_1.value.isEmail('phil@foo.')).to.eql(false);
        (0, chai_1.expect)(_1.value.isEmail('@foo.com')).to.eql(false);
        (0, chai_1.expect)(_1.value.isEmail('foo.com')).to.eql(false);
    });
    it('is an email', function () {
        (0, chai_1.expect)(_1.value.isEmail('phil@foo.com')).to.eql(true);
        (0, chai_1.expect)(_1.value.isEmail('1@1.nz')).to.eql(true);
    });
});
