"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var _1 = require(".");
var defaultValue = _1.value.defaultValue;
describe('defaultValue', function () {
    it('does not change the given value', function () {
        (0, chai_1.expect)(defaultValue(1)).to.eql(1);
        (0, chai_1.expect)(defaultValue(1, 2)).to.eql(1);
        (0, chai_1.expect)(defaultValue(0, 2)).to.eql(0);
        (0, chai_1.expect)(defaultValue(undefined)).to.eql(undefined);
        (0, chai_1.expect)(defaultValue('foo', 'bar')).to.eql('foo');
        (0, chai_1.expect)(defaultValue('', 'bar')).to.eql('');
        (0, chai_1.expect)(defaultValue(true, false)).to.eql(true);
        (0, chai_1.expect)(defaultValue(false, true)).to.eql(false);
    });
    it('uses the given default value', function () {
        (0, chai_1.expect)(defaultValue(undefined, 1)).to.eql(1);
        (0, chai_1.expect)(defaultValue(undefined, 'bar')).to.eql('bar');
        (0, chai_1.expect)(defaultValue('' || undefined, 'bar')).to.eql('bar');
        (0, chai_1.expect)(defaultValue(undefined, { foo: 123 })).to.eql({
            foo: 123,
        });
        (0, chai_1.expect)(defaultValue(undefined, false)).to.eql(false);
        (0, chai_1.expect)(defaultValue(undefined, true)).to.eql(true);
    });
});
describe('deleteUndefined', function () {
    it('retains existing values, removes undefined', function () {
        var res = _1.value.deleteUndefined({
            nothing: undefined,
            yes: true,
            no: false,
            zero: 0,
            value: null,
            text: '',
        });
        (0, chai_1.expect)(res).to.eql({
            yes: true,
            no: false,
            zero: 0,
            value: null,
            text: '',
        });
    });
});
describe('deleteEmpty', function () {
    it('deletes empty/undefined values', function () {
        var res = _1.value.deleteEmpty({
            nothing: undefined,
            yes: true,
            no: false,
            zero: 0,
            value: null,
            text: '',
        });
        (0, chai_1.expect)(res).to.eql({
            yes: true,
            no: false,
            zero: 0,
            value: null,
        });
    });
});
describe('isStatusOk', function () {
    it('is ok', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            (0, chai_1.expect)(_1.value.isStatusOk(200)).to.eql(true);
            (0, chai_1.expect)(_1.value.isStatusOk(201)).to.eql(true);
            return [2];
        });
    }); });
    it('is not ok', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            (0, chai_1.expect)(_1.value.isStatusOk(404)).to.eql(false);
            (0, chai_1.expect)(_1.value.isStatusOk(500)).to.eql(false);
            (0, chai_1.expect)(_1.value.isStatusOk(0)).to.eql(false);
            (0, chai_1.expect)(_1.value.isStatusOk(undefined)).to.eql(false);
            return [2];
        });
    }); });
});
describe('plural', function () {
    it('singular', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            (0, chai_1.expect)(_1.value.plural(1, 'item')).to.eql('item');
            (0, chai_1.expect)(_1.value.plural(-1, 'item')).to.eql('item');
            (0, chai_1.expect)(_1.value.plural(1, 'item', 'items')).to.eql('item');
            (0, chai_1.expect)(_1.value.plural(-1, 'item', 'items')).to.eql('item');
            return [2];
        });
    }); });
    it('plural', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            (0, chai_1.expect)(_1.value.plural(0, 'item', 'items')).to.eql('items');
            (0, chai_1.expect)(_1.value.plural(2, 'item', 'items')).to.eql('items');
            (0, chai_1.expect)(_1.value.plural(-2, 'item', 'items')).to.eql('items');
            (0, chai_1.expect)(_1.value.plural(999, 'item', 'items')).to.eql('items');
            return [2];
        });
    }); });
    it('inferred "s"', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            (0, chai_1.expect)(_1.value.plural(0, 'item')).to.eql('items');
            (0, chai_1.expect)(_1.value.plural(2, 'item')).to.eql('items');
            (0, chai_1.expect)(_1.value.plural(-2, 'item')).to.eql('items');
            (0, chai_1.expect)(_1.value.plural(999, 'item')).to.eql('items');
            return [2];
        });
    }); });
});
